@@ -5,5 +5,7 @@ import { QueryTemplateRow } from '../types';
 export const canEditQuery = (query: QueryTemplateRow) => {
   const userIsAuthor = query.user?.uid?.replace('user:', '') === contextSrv.user.uid;
   const userIsAdmin = contextSrv.hasRole('Admin');
-  return userIsAuthor || userIsAdmin;
+  const userIsViewer = contextSrv.hasRole('Viewer');
+
+  return (userIsAuthor && !userIsViewer) || userIsAdmin;
 };
